-- Tabela SimulacaoPrecoCusto
CREATE TABLE SimulacaoPrecoCusto (
   CodSimulacao INT NOT NULL,
   CodPro CHAR(5),
   rFornecedor INT,
   PrecoLista NUMERIC(20,5),
   Data DATE);

-- Chave Primria Tabela SimulacaoPrecoCusto
ALTER TABLE SimulacaoPrecoCusto ADD CONSTRAINT PK_SIMULACAOPRECOCUSTO PRIMARY KEY (CodSimulacao);

-- Auto Incremento da Tabela SimulacaoPrecoCusto
CREATE SEQUENCE SIMULACAOPRECOCUSTO_SEQ  MINVALUE 1  MAXVALUE 999999999999999999999999999  INCREMENT BY 1  NOCYCLE  NOORDER;

CREATE OR REPLACE TRIGGER SIMULACAOPRECOCUSTO_I
BEFORE
INSERT ON SIMULACAOPRECOCUSTO FOR EACH ROW DECLARE nContador NUMBER;
BEGIN
IF :NEW.CODSIMULACAO=0 OR :NEW.CODSIMULACAO IS NULL THEN
   SELECT SIMULACAOPRECOCUSTO_SEQ.NEXTVAL INTO nContador FROM DUAL;
   :NEW.CODSIMULACAO := nContador;
END IF;
END;
/

commit;

-- Tabela ItemSimulacaoPrecoCusto
CREATE TABLE ItemSimulacaoPrecoCusto (
   Item INT NOT NULL,
   CodSimulacao INT NOT NULL,
   Prorrogacao INT,
   PrazoPagamento INT,
   Bonificacao NUMERIC(5,2),
   PrecoCusto NUMERIC(20,5),
   MargemZero NUMERIC(20,5),
   PrecoVenda NUMERIC(20,5));

-- Chave Primria Tabela ItemSimulacaoPrecoCusto
ALTER TABLE ItemSimulacaoPrecoCusto ADD CONSTRAINT PK_ITEMSIMULACAOPRECOCUSTO PRIMARY KEY (Item, CodSimulacao);

-- Auto Incremento da Tabela ItemSimulacaoPrecoCusto
CREATE SEQUENCE ITEMSIMULACAOPRECOCUSTO_SEQ  MINVALUE 1  MAXVALUE 999999999999999999999999999  INCREMENT BY 1  NOCYCLE  NOORDER;

CREATE OR REPLACE TRIGGER ITEMSIMULACAOPRECOCUSTO_I
BEFORE
INSERT ON ITEMSIMULACAOPRECOCUSTO FOR EACH ROW DECLARE nContador NUMBER;
BEGIN
   IF :NEW.ITEM=0 OR :NEW.ITEM IS NULL THEN
      SELECT ITEMSIMULACAOPRECOCUSTO_SEQ.NEXTVAL INTO nContador FROM DUAL;
      :NEW.ITEM := nContador;
   END IF;
END;
/

commit;

-- Tabela ComposicaoSimulacaoPrecoCusto
CREATE TABLE ComposicaoSimulacaoPrecoCusto (
   OID INT NOT NULL,
   rItemSimulacao INT,
   rTipoPesquisa INT,
   rCalculo INT,
   Valor NUMERIC(20,5));

-- Chave Primria da Tabela ComposicaoSimulacaoPrecoCusto
ALTER TABLE ComposicaoSimulacaoPrecoCusto ADD CONSTRAINT PK_COMPSIMULACAOPRECOCUSTO PRIMARY KEY (OID);

commit;

-- Parmetro "Taxa de inflao de estoque"
insert into item (rescopo, criadopor, atualizadopor, codigo, criadoem, atualizadoem , observacao, nome, cid, oid, excluido) values (7           ,1,1,' ','01/01/01','01/01/01','Armazena o valor da taxa de inflao do estoque para os clculos de simulao de preo de custo.','Taxa de inflao de estoque',18,32390,0);
insert into categoria (rsuper, nomeinterno, oid) values (2376 ,'TAXA_INFLACAO_ESTOQUE',32390);
insert into dadoadicional ( RCLASSECONCRETA,RAPLICATIVO,RDOMINIO,RLISTA,RTIPO,RITEM,RESTRICAO,VISIVEL,MASCARA,PADRAO,MAXIMO,MINIMO,VALOR,OID) values (7,1884 ,15812,7,32390,10128,0.0,0.0,'',' ',0.0,0.0,'PA119712',32389);
insert into aditivo (RITEM,RDEFINICAO,SVALOR,OID) values (1    ,32389,'',32391);
commit;

-- Parmetro Abater PIS/COFINS no preo de custo do produto / PA 113757
insert into item (rescopo, criadopor, atualizadopor, codigo, criadoem, atualizadoem , observacao, nome, cid, oid, excluido) values (7           ,1,1,' ','01/01/01','01/01/01','Parmetro destinado a determinar se o preo de custo do produto vir abatido de PIS/COFINS.','Abater PIS/COFINS no preo de custo do produto',18,32356,0);
insert into categoria (rsuper, nomeinterno, oid) values (2376 ,'ABATER_PIS_COFINS_NO_PRECO_DE_CUSTO_PRODUTO ',32356);
insert into dadoadicional ( RCLASSECONCRETA,RAPLICATIVO,RDOMINIO,RLISTA,RTIPO,RITEM,RESTRICAO,VISIVEL,MASCARA,PADRAO,MAXIMO,MINIMO,VALOR,OID) values (7,1884 ,15812,7,32356,10128,0.0,0.0,'',' ',0.0,0.0,'PA113757',32355);
insert into aditivo (RITEM,RDEFINICAO,SVALOR,OID) values (1    ,32355,'',32357);
commit;